@@ -106,13 +106,17 @@ def makeRi(A, initial_cov):
     return Ri
 
 
-def mud_sol(A, b, y, mean, cov, data_cov=None):
+def mud_sol(A, b, y=None, mean=None, cov=None, data_cov=None):
     """
-    Definitely works
+    Definitely works.
+    For SWE problem, we are inverting N(0,1).
+    This is the defautl value for `data_cov`.
     """
-    if data_cov is None:
-        # for SWE problem, we are inverting N(0,1).
-        data_cov = np.eye(A.shape[0])
+    if data_cov is None: data_cov = np.eye(A.shape[0])
+    if cov is None: cov = np.eye(A.shape[1])
+    if mean is None: mean = np.zeros((A.shape[1],1))
+    if y is None: y = np.zeros((A.shape[0],1))
+
     x = y - b - A@mean
     # compute once for re-use
     pre = A@cov@A.T
