@@ -1,5 +1,5 @@
 import numpy as np
-from scipy.special import erfinv
+from pyerf import erfinv
 
 def std_from_equipment(tolerance=0.1, probability=0.95):
     """
@@ -54,7 +54,7 @@ def createRandomLinearMap(dim_input, dim_output, dist='normal', repeated=False):
     if  dist == 'normal':
         M     = np.random.randn(dim_output, dim_input)
     else:
-        M     = np.rand.rand(dim_output, dim_input)
+        M     = np.random.rand(dim_output, dim_input)
     if repeated: # just use first row
         M     = np.array(list(M[0,:])*dim_output).reshape(dim_output, dim_input)
 
@@ -141,7 +141,7 @@ def null_space(A, rcond=None):
     --------
     One-dimensional null space:
 
-    >>> from scipy.linalg import null_space
+    >>> from mud.util import null_space
     >>> A = np.array([[1, 1], [1, 1]])
     >>> ns = null_space(A)
     >>> ns * np.sign(ns[0,0])  # Remove the sign ambiguity of the vector
